@Filename: TCap.s
@Part: ADuC7020,ADuC7024,ADuC7026.
@Created: 27/08/2004
@Updated: 28/06/2005
@Author: Barry Broderick
@This file is in beta sampling.

.include        "ADuC7020.equ"
.ARM

@ TCap==========Reads timer T capture register and sets the Capture register.
@ C Function prototype: int TCap(int iT, int iCapCh);
@iT:{0,1,2,3}
@iCapCh:{I0FF,IT0,IT1,IT2,IT3,IFLA,IADC,IPLLL,II2C0S,II2C0M,II2C1M,ISPIS,ISPIM,IUART,IEX0,ICMP,IPSM,IEX1,IPLA0,IPLA1,IEX2,IEX3,IPWMT,IPWMS}
@ Description of Function: Reads T capture register TCAP (only for T1).
@ User interface:
@   Set iT to desired Timer, 0 to 3
@   Set iCapCh to the desired capture trigger source.
@     -1 = Only read capture register.
@       0 = IOFF -> capture off.    14 = IUART => UART
@       2 = IT0 => T0               15 = IEX0 => External interupt 0
@       3 = IT1 => T1               16 = ICMP => Comparator
@       4 = IT2 => T2               17 = IPSM => PSM
@       5 = IT3 => T3               18 = IEX1 => External interupt 1
@       6 = IFLA => Flash           19 = IPLA0 => PLA0
@       7 = IADC => ADC ready       20 = IPLA1 => PLA1
@       8 = IPLLL => PLL lock       21 = IEX2 => External interupt 2
@       9 = II2C0S => I2C0 slave    22 = IEX3 => External interupt 3
@       10 = II2C0M => I2C0 master  23 = IPWMT => PWM trip
@       11 = II2C1M => I2C1 master  24 = IPWMS => PWM sync
@       12 = ISPIS => SPI slave
@       13 = ISPIM => SPI master
@       Note: This table mirrors the IRQ/FIQ MMR bit definitions 
@           except for bit 0 and 1. The values are 2 more than
@           bits 12 to 16 of T1CON.
@   Call TCap().
@   Returns TCAP in r0.
@ Robustness:
@   Interupt functionality may be added separately.
@  Only works for T1. Will have no effect if any other timer is input.
@ Side effects: Corrupts r0 and r3.

.GLOBAL TCap
TCap:    mov      r3,#0xff0000            @r3 = Z_BASE
         orr      r3,r3,#0xff000000
         cmp      r1,#-0x01               @Compare r1 with -1
         beq      TRCap                   @ if equal only read T1Cap

         mov      r3,#0xff0000            @r3 = Z_BASE
         orr      r3,r3,#0xff000000
         orr      r3,r3,r0,lsl#5          @r3 = r0 << 5;

         ldr      r2,[r3,#T0CON_OFFSET]   @ if not equal, r2 = TCON;  
         orr      r2,r2,r1,lsl#0x0C       @ if not equal copy iCapCh into r2
         orr      r2,r2,#0x20000          @ if not equal set event select bit.
      
         str      r2,[r3,#T1CON_OFFSET]   @Write to CON
TRCap:   ldr      r0,[r3,#T1CAP_OFFSET]   @Get CAP.

         bx       lr
